<a id="widgets.buttons.*"></a>

## \*

<a id="widgets.buttons.StateButton"></a>

## StateButton Objects

```python
class StateButton(QPushButton)
```

<a id="widgets.buttons.StateButton.state_changed"></a>

#### state\_changed

<a id="widgets.buttons.StateButton.state"></a>

#### state

```python
@property
def state()
```

<a id="widgets.buttons.StateButton.state"></a>

#### state

```python
@state.setter
def state(state)
```

<a id="widgets.buttons.StateButton.__init__"></a>

#### \_\_init\_\_

```python
def __init__(*args, **kwargs)
```

<a id="widgets.buttons.StateButton.next_state"></a>

#### next\_state

```python
def next_state()
```

<a id="widgets.buttons.StateButton.update_icon"></a>

#### update\_icon

```python
def update_icon()
```

<a id="widgets.buttons.IconToggleButton"></a>

## IconToggleButton Objects

```python
class IconToggleButton(QPushButton)
```

<a id="widgets.buttons.IconToggleButton.__init__"></a>

#### \_\_init\_\_

```python
def __init__(*args, **kwargs)
```

<a id="widgets.buttons.IconToggleButton.update_icon"></a>

#### update\_icon

```python
def update_icon()
```

<a id="widgets.buttons.ConfirmToggleButton"></a>

## ConfirmToggleButton Objects

```python
class ConfirmToggleButton(QPushButton)
```

<a id="widgets.buttons.ConfirmToggleButton._state_changed"></a>

#### \_state\_changed

<a id="widgets.buttons.ConfirmToggleButton.state"></a>

#### state

```python
@property
def state()
```

<a id="widgets.buttons.ConfirmToggleButton.state"></a>

#### state

```python
@state.setter
def state(state)
```

<a id="widgets.buttons.ConfirmToggleButton.__init__"></a>

#### \_\_init\_\_

```python
def __init__(*args, **kwargs)
```

<a id="widgets.buttons.ConfirmToggleButton.uncheck"></a>

#### uncheck

```python
def uncheck()
```

<a id="widgets.buttons.ConfirmToggleButton.confirm"></a>

#### confirm

```python
def confirm()
```

<a id="widgets.buttons.ConfirmToggleButton.check"></a>

#### check

```python
def check()
```

<a id="widgets.buttons.ConfirmToggleButton.next_state"></a>

#### next\_state

```python
def next_state()
```

<a id="widgets.buttons.ConfirmToggleButton.update_icon"></a>

#### update\_icon

```python
def update_icon()
```

